wsic.metadata package
=====================

Submodules
----------

wsic.metadata.ngff module
-------------------------

.. automodule:: wsic.metadata.ngff
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: wsic.metadata
   :members:
   :undoc-members:
   :show-inheritance:
